var model = avalon.define({
	$id: 'index',
	query: {
		keywords: ""
	},
	// 重置查询条件
	_clear: function() {
		model.query = {
			keywords: ""
		};
	}
});

var THISPAGE = {
	_init: function() {
		var self = this;
		self._render();
		self._bindEvent();
	},
	_render: function() {
		var self = this;
		self._loadGrid();
	},
	_bindEvent: function() {
		var self = this;
		// 搜索
		$("#J_search").click(function() {
			self._reloadData()
		});
		// 新增
		$("#J_add").on("click",
			function(e) {
				e.preventDefault();
				self._giveDialogAdd("");
			});
		// 批量导入
		$("#J_batchImport").on("click",
			function(e) {
				e.preventDefault();
				self._giveDialogBatchImport();
			});
		// 刷新
		$("#J_refresh").click(function() {
			self._reloadData();
		});
		// 批量删除（放入回收站）
		$("#J_batchDel").click(function(e) {
			e.preventDefault();
			var zTree = $.fn.zTree.getZTreeObj("tree");
			var nodes = zTree.getCheckedNodes(true); //获取选中的节点
			var deleteNodeIds = "";
			var nodeLength = nodes.length;
			//拼装要删除的id，以逗号隔开的字符串
			for (var i = 0; i < nodeLength; i++) {
				deleteNodeIds += nodes[i].id;
				if (i + 1 != nodeLength) {
					deleteNodeIds += ",";
				}
			};
			//将数据放入回收站
			if (deleteNodeIds) {
				$.dialog.confirm("您确定要删除选中的权限吗？", function() {
					self._putRecycle(deleteNodeIds);
				});
			} else {
				parent.Public.tips({
					type: 2,
					content: "请选择需要删除的权限"
				});
			}
		});
	},

	//加载权限树数据
	_loadGrid: function() {
		var self = this;
		var zTree; //zTree对象
		var url = "/author/getAuthorTreeList";
		//zTree基本设置  
		var setting = {
			treeId: "tree",
			treeObj: null,
			view: {
				showTitle: true,
				expandFlag: true,
				addHoverDom: addHoverDom,
				removeHoverDom: removeHoverDom
			},
			edit: {
				enable: true,
				showRemoveBtn: false,
				showRenameBtn: false,
			},
			async: {
				autoParam: ["id=id"],
				//节点ID作为参数id上传
				type: "get"
			},
			check: {
				//是否启用checkBox
				enable: true,
				//true / false 分别表示 触发 / 不触发 事件回调函数
				autoCheckTrigger: false,
				//框框类型
				chkStyle: "checkbox",
				//checkbox 勾选操作，只影响父级节点；取消勾选操作，只影响子级节点
				chkboxType: {
					"Y": "s",
					"N": "s"
				}
			},
			data: {
				keep: {
					leaf: false,
					parent: false
				},
				key: {
					children: "child",
					name: "authorName",
					title: "authorName"
				},
				simpleData: {
					enable: false,
					idKey: "id",
					pIdKey: "parentId",
					rootPId: null
				}
			},
			callback: {
				beforeDrop: zTreeBeforeDrop
			}

		};

		function zTreeBeforeDrop(treeId, treeNodes, targetNode, moveType) {
			if (targetNode == null || (moveType != "inner" && !targetNode.parentTId)) {
				return false;
			}
			for (var i = treeNodes.length - 1; i >= 0; i--) {
				updateData(treeNodes[i].id, targetNode.id, treeNodes[i].authorName, treeNodes[i].authorCode);
			};
		};

		function updateData(id, parentId, authorName, authorCode) {
			Public.ajaxPost("/author/update", {
				'id': id,
				'parentId': parentId,
				'authorName': authorName,
				'authorCode': authorCode
			}, function(res) {
				if (res.successed) {
					// 成功提示框
					parent.parent.Public.tips({
						content: "修改成功！"
					});

				} else {
					parent.parent.Public.tips({
						type: 1,
						content: "修改失败！" + res.errorDesc
					});
				}
			});
		};

		//初始化权限树数据
		function inintTree() {
			$.ajax({
				data: model.query.$model,
				async: false,
				cache: false,
				type: 'GET',
				dataType: "json",
				url: url,
				//请求的action路径  
				error: function() { //请求失败处理函数  
					parent.Public.tips({
						type: 1,
						content: res.errorDesc
					})
				},
				success: function(res) { //请求成功后处理函数。    
					if (res.successed) {
						//初始化数据
						zTree = $.fn.zTree.init($("#tree"), setting, res.returnValue);
						zTree.expandAll(true);
					} else {
						parent.Public.tips({
							type: 1,
							content: res.errorDesc
						})
					}
				}

			});
		};

		//添加悬浮时自定义dom标签
		function addHoverDom(treeId, treeNode) {
			var aObj = $("#" + treeNode.tId + "_a");
			if ($("#diyBtn_my_" + treeNode.id).length > 0) return;
			var editStr = "<div style='display:inline;' id='diyBtn_my_" + treeNode.id + "'>";
			editStr += "<span style='color:blue; padding-left: 30px;' id='diyBtn_addchild_" + treeNode.id + "'title='添加下级' >添加下级</span>";
			editStr += "<span style='color:blue; padding-left: 30px;' id='diyBtn_view_" + treeNode.id + "'title='查看' >查看</span>";
			editStr += "<span style='color:blue; padding-left: 30px;' id='diyBtn_edit_" + treeNode.id + "'title='编辑' >编辑</span>";
			editStr += "<span style='color:blue; padding-left: 30px;' id='diyBtn_delete_" + treeNode.id + "'title='删除' >删除</span>";
			editStr += "</div>";
			aObj.append(editStr);
			//添加下级
			var btnView = $("#diyBtn_addchild_" + treeNode.id);
			if (btnView) btnView.bind("click", function() {
				self._giveDialogAdd(treeNode.id);
			});
			//查看
			var btnView = $("#diyBtn_view_" + treeNode.id);
			if (btnView) btnView.bind("click", function() {
				self._giveDialogView(treeNode.id);
			});
			//编辑
			var btnEdit = $("#diyBtn_edit_" + treeNode.id);
			if (btnEdit) btnEdit.bind("click", function() {
				self._giveDialogEdit(treeNode.id);
			});
			//删除（放入回收站）
			var btnDelete = $("#diyBtn_delete_" + treeNode.id);
			if (btnDelete) btnDelete.bind("click", function() {
				removeNode(treeId, treeNode);
			});
		};

		//移除悬浮时显示的自定义dom标签
		function removeHoverDom(treeId, treeNode) {
			$("#diyBtn_my_" + treeNode.id).unbind().remove();
		};

		//放入回收站之前事件
		function removeNode(treeId, treeNode) {
			var deleteNodeName = treeNode.authorName; //删除的节点名称
			var deleteNodeId = treeNode.id; //删除的节点id
			$.dialog.confirm("您确认要将权限<span style='color:red;'>\"" + deleteNodeName + "\"</span>删除吗？",
				function() {
					self._putRecycle(deleteNodeId);
				}
			);
		};
		//初始化
		inintTree();
	},
	//查看页面
	_giveDialogView: function(nodeId) {
		var self = this;
		$.dialog({
			init: function() {
				var height = $(window).height() - 65;
				$(".ui_main").css("height", height);
			},

			id: "moreCon",
			min: true,
			max: true,
			title: "查看权限",
			resize: true,
			lock: true,
			content: "url:" + "/author/view.html",
			data: {
				id: nodeId
			}
		}).max();
	},
	//新增
	_giveDialogAdd: function(parentId) {
		var self = this;
		$.dialog({
			init: function() {
				var height = $(window).height() - 65;
				$(".ui_main").css("height", height);
			},
			title: "新增权限",
			content: "url:" + "/author/add.html",
			data: {
				"parentId": parentId
			},

			max: true,
			min: false,
			cache: false,
			resize: true,
			lock: true
		}).max()
	},
	//编辑
	_giveDialogEdit: function(nodeId) {
		var self = this;
		$.dialog({
			init: function() {
				var height = $(window).height() - 65;
				$(".ui_main").css("height", height);
			},
			title: "修改权限",
			content: "url:" + "/author/edit.html",
			data: {
				"id": nodeId
			},

			max: true,
			min: false,
			cache: false,
			resize: true,
			lock: true
		}).max()
	},
	//放入回收站
	_putRecycle: function(deleteNodeId) {
		var self = this;

		Public.ajaxPost("/author/delete", {
				ids: deleteNodeId
			},
			function(res) {
				if (res.successed) {

					self._reloadData();

				} else {
					parent.Public.tips({
						type: 1,
						content: res.errorDesc
					})
				}

			})
		self._loadGrid();
	},
	//刷新
	_reloadData: function() {
		var self = this;
		self._loadGrid();
	},
	//新增
	_giveDialogBatchImport: function() {
		var self = this;
		$.dialog({
			init: function() {
				var height = $(window).height() - 65;
				$(".ui_main").css("height", height);
			},
			title: "批量导入",
			content: "url:" + "/author/batchImport.html",

			max: true,
			min: false,
			cache: false,
			resize: true,
			lock: true

		}).max()
	}
};

THISPAGE._init();